package com.ruoyi.system.service.impl;

import com.ruoyi.common.core.domain.entity.LabelInfo;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.mapper.LabelInfoMapper;
import com.ruoyi.system.service.ILabelInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 【请填写功能名称】Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-07-15
 */
@Service
public class LabelInfoServiceImpl implements ILabelInfoService 
{
    @Autowired
    private LabelInfoMapper labelInfoMapper;

    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public LabelInfo selectLabelInfoById(Long id)
    {
        return labelInfoMapper.selectLabelInfoById(id);
    }

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param labelInfo 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<LabelInfo> selectLabelInfoList(LabelInfo labelInfo)
    {
        return labelInfoMapper.selectLabelInfoList(labelInfo);
    }

    /**
     * 新增【请填写功能名称】
     * 
     * @param labelInfo 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertLabelInfo(LabelInfo labelInfo)
    {
        labelInfo.setCreateTime(DateUtils.getNowDate());
        return labelInfoMapper.insertLabelInfo(labelInfo);
    }

    /**
     * 修改【请填写功能名称】
     * 
     * @param labelInfo 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateLabelInfo(LabelInfo labelInfo)
    {
        labelInfo.setUpdateTime(DateUtils.getNowDate());
        return labelInfoMapper.updateLabelInfo(labelInfo);
    }

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteLabelInfoByIds(Long[] ids)
    {
        return labelInfoMapper.deleteLabelInfoByIds(ids);
    }

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteLabelInfoById(Long id)
    {
        return labelInfoMapper.deleteLabelInfoById(id);
    }
}
